!*****************************************************************************

!  MPFUN-MPFR: An MPFR-based Fortran arbitrary precision computation package
!  Global data definition module (module MPFUNA)

!  Revision date:  9 Jan 2022

!  AUTHOR:
!    David H. Bailey
!    Lawrence Berkeley National Lab (retired) and University of California, Davis
!    Email: dhbailey@lbl.gov

!  COPYRIGHT AND DISCLAIMER:
!    All software in this package (c) 2022 David H. Bailey.
!    By downloading or using this software you agree to the copyright, disclaimer
!    and license agreement in the accompanying file DISCLAIMER.txt.

!  PURPOSE OF PACKAGE:
!    This package permits one to perform floating-point computations (real and
!    complex) to arbitrarily high numeric precision, by making only relatively
!    minor changes to existing Fortran-90 programs.  All basic arithmetic
!    operations and transcendental functions are supported, together with several
!    special functions.

!    In addition to fast execution times, one key feature of this package is a
!    100% THREAD-SAFE design, which means that user-level applications can be
!    easily converted for parallel execution, say using a threaded parallel
!    environment such as OpenMP.

!    This version differs from the MPFUN20-Fort version by the same author in that
!    this is based on MPFR, which presently is the fastest available low-level
!    package for high-precision floating-point computation.  At the Fortran user
!    level, most application codes written for MPFUN20-Fort may be compiled with
!    MPFUN-MPFR -- i.e., MPFUN-MPFR is plug-compatible with MPFUN20-Fort.

!  DOCUMENTATION:
!    A detailed description of this package, and instructions for compiling
!    and testing this program on various specific systems are included in the
!    README file accompanying this package, and, in more detail, in the
!    following technical paper:

!    David H. Bailey, "MPFUN2020: A new thread-safe arbitrary precision package," 
!    available at http://www.davidhbailey.com/dhbpapers/mpfun2020.pdf.

!  DESCRIPTION OF THIS MODULE (MPFUNA):
!    This module contains some global parameter definitions.

module mpfuna
implicit none

!----------------------------------------------------------------------------

!   General integer constants:

!   Name     Default   Description
!   mpiknd        8    Kind parameter for long integers (usually 8).
!   mpndpw       18    Largest n such that 10^n <= mpbdx (see below).
!   mpldb         6    Logical device number for output of error messages.
!   mpl2pi     1041    Precision in words of precomputed log(2), pi and egamma below.
!                      Default 1111 words corresponds to approximately 20,000 digits.
!                      If higher precision is required, call mpinitran or mpinit.
!   mpnbt        64    Number of significant bits in one mantissa word.
!   mpnstr     2048    Maximum length of certain input character strings.
!                        See usage in mpinp of module MPFUNC.
!   mpoutln      80    Length of output lines.  See usage in mpout of MPFUNC.
!   mprknd        8    Kind parameter for double floats (usually 8).
!   mprnd         0    MPFR rounding mode.
!   mprknd2      16    Kind parameter for quad floats (if available; usually 16).
!                      If quad floating (128-bit) is not supported on the processor,
!                      then mprknd2 = -1.

!   Long integer constants

!   mpnan     -2^63+2  MPFR NAN flag.
!   mpzero    -2^63+1  MPFR zero flag.

!   Double precision constants:

!   mpbdx      2^64    2^mpnbt, the radix for MP numbers.
!   mpbx2      2^128   Square of radix.
!   mpb13x     2^13    Constant for checking the 40-bit restriction.
!   mpb23x     2^23    Constant for checking the 90-bit quad restriction.
!   mpdpw  Log10(2^64) DP approximation to number of digits per mantissa word.
!   mpexpmx   2^31     Largest permissible exponent.
!   mprdfz    1/2^50   "Fuzz" for comparing DP values.
!   mprdx   2^(-64)    Reciprocal of radix.
!   mprx2   2^(-128)   Reciprocal of square of radix.
!   mprandx  5501758857861179  Multiplier for pseudorandom number generator.

!   Integer parameter for log(2), pi and egamma arrays:

!   mplconx    100000  Max size of log(2) and pi arrays. This is large enough to
!                      support precision levels over one million digits.

integer, public:: mpiknd, mpndpw, mpldb, mpl2pi, mpnbt, mpnstr, mpoutln, mprknd, mprnd, &
  mprknd2
parameter (mpiknd = selected_int_kind (18), mpndpw = 18, mpldb = 6, mpl2pi = 1041, &
  mpnbt = 64, mpnstr = 2048, mpoutln = 80, mprknd = selected_real_kind (15, 300), &
  mprnd = 0, mprknd2 = selected_real_kind (30, 300))
integer(mpiknd), public:: mpnan, mpzero
real (mprknd), public:: mpbdx, mpbx2, mpdpw, mpexpmx, mprdfz, mprdx, mprx2, mpb13x, mpb23x, &
  mprandx
parameter (mpnan = -9223372036854775806_mpiknd, mpzero = -9223372036854775807_mpiknd)
parameter (mpbdx = 2.d0 ** mpnbt, mpbx2 = mpbdx**2, mpdpw = 19.265919722494796d0, &
  mpexpmx = 2.d0**31, mprdfz = 0.5d0**50, mprdx = 0.5d0 ** mpnbt, mprx2 = mprdx**2, &
  mpb13x = 2.d0 ** 13, mpb23x = 2.d0 ** 23, mprandx = 5501758857861179.d0)
integer, public:: mplconx
parameter (mplconx = 100000)

!  These two lines are for debug and timing (for internal use only):

integer, dimension(10):: mpdeb = 0
real (mprknd), dimension(10):: mptm = 0.d0

!  The following data arrays contain the values of log(2), pi and egamma to mpl2pi words or
!  roughly 20,000 digits (by default). For higher precision, call mpinitran or mpinit.

integer (mpiknd), public:: mplog2con(0:mplconx-1), mppicon(0:mplconx-1), mpegammacon(0:mplconx-1)
integer, private:: i, i8
parameter (i8 = mpiknd)

data (mplog2con(i), i =     0,   199) / &
                1047_i8,               66624_i8,                   1_i8,                   0_i8, &
          6165509928_i8, 2640603018459977993_i8,-5799772836773545310_i8,-1651073962462720506_i8, &
 5712976152627560104_i8, 4922562688564395275_i8, 4667361634293366926_i8,   56841936167960499_i8, &
-8750694618017987158_i8,-5143040024492655365_i8, 4765404803869035240_i8, 9080272662352140151_i8, &
 2481993234907462955_i8, 7020117126283490984_i8,-5672767882055905709_i8,-3189794936277264509_i8, &
-2186800270993854547_i8, 7334912395624856152_i8, 5925025582620789319_i8, 3404623153247689233_i8, &
-7054358268756209636_i8, 2110683649311721288_i8, 6607201319504541872_i8, 6989927054720805484_i8, &
 9125547988552479891_i8,-3679333087005941564_i8,-7949282872585851969_i8, 1818895973708368496_i8, &
-9196712863651177965_i8,-6985151832991831983_i8,-6307966390558047073_i8,-2047509952508559003_i8, &
-1182762114111240221_i8,-4370048193740823333_i8, 4983445059758406107_i8,  762618495228093671_i8, &
 1240095652843298212_i8,-7570557149048742019_i8, 1102643508349838930_i8, 6488519502469408351_i8, &
-1670140026310811602_i8,-5786615821214460739_i8,-5364646661433992421_i8,-2407907018429377909_i8, &
-2691359750662766143_i8, 8012713412105625898_i8, 1199112756750729364_i8,-7038697495920446408_i8, &
-2031607008690314340_i8,-2155478151748420987_i8, 1240884204910989785_i8,-2601638102710357238_i8, &
 8074917353398728957_i8, 4171177671881792052_i8,-9007673642079596120_i8, 5067661917519366988_i8, &
  819783957327266841_i8,-1471773800356186933_i8,-4154131436038229789_i8,-6712478114597475561_i8, &
-7716454604958004013_i8,-1446928077748650028_i8, 9011867338057696008_i8, 4975259129648706158_i8, &
-3263543015592073115_i8,-7222498388967084989_i8, 5414821465131021799_i8,-1817212349310046264_i8, &
 8054553262596645227_i8,-6756969984429666628_i8,-3593070753944228378_i8,-7836685189412897877_i8, &
 4266429146273074535_i8,-1330116235189821737_i8,-7217131186132612468_i8, 5974490812970428433_i8, &
 6689338656073994556_i8, 4027431625439490199_i8,  -96872100828599343_i8,-2120989886595012088_i8, &
-4385699581031422788_i8,-8095917229612644077_i8, 4567982739759659437_i8, 6003670897834809661_i8, &
 8394534462298423803_i8,  633789278652791253_i8, 3566983204078106990_i8,-7211731693275008259_i8, &
 8860002958857965759_i8,-5384525715610281193_i8, -369402348845180484_i8, 5718917653328254605_i8, &
-2243595052872020848_i8, 1310530419115270402_i8,-7016683057706115503_i8,-3930458422235209921_i8, &
-6965623170733289223_i8, 2253421496339707193_i8, 1390257521886875371_i8,-1453350887260558919_i8, &
 -195970377362568933_i8, 6257039322890352825_i8,-6908518472456200236_i8,-1673423715524127810_i8, &
 3087969003597149325_i8, -478243386729715698_i8,-1373104867694690075_i8, 1812089647048522905_i8, &
-2816524739896713568_i8,-1946322870744452107_i8, 4123533472091305795_i8, 2914079602762566800_i8, &
-2461679517036301934_i8,-6125187338888695605_i8, 1842063729564621381_i8, 3108486007635834673_i8, &
-1754725623018069651_i8, 3953765102101484779_i8,-8541466841061673000_i8, 1431366495359917965_i8, &
 6699343422349559462_i8,-4012832655344514902_i8,-6157822055511931390_i8, 8984354136231791201_i8, &
 5416965883874171441_i8,-1180996604043567301_i8,-7948951309285308101_i8, 3422805174183408775_i8, &
-1430387094921439951_i8, 4634780956125023898_i8,-2230909964879474706_i8,-2126886440302905627_i8, &
-2723526215223565312_i8, 8792106511623669824_i8,-8506371173325886196_i8, 5426550128123846648_i8, &
 2693364810741812621_i8, 3136297140155510002_i8, 6564652140369048858_i8,-5423596892986810533_i8, &
-3705465787892049400_i8, 3532033273124189977_i8, 4082748428122109334_i8,-7746168902308696404_i8, &
-1540932802856760893_i8, -911802094334468499_i8,-7798245290471412318_i8,-2944320183277666548_i8, &
-2493111023520177961_i8,-8930042343529734801_i8, 8196541688880351499_i8,-7146299548675137960_i8, &
-2115959454380020048_i8, 4295141467766353226_i8,-1122017199577949245_i8, 5006033431617554996_i8, &
 4179200129603874591_i8, 3751295234274947137_i8,  701902803701061626_i8,-4942601132180778004_i8, &
 1064661801440580842_i8, 8387751497817661444_i8, 4645944223872900431_i8,-4495161312101026589_i8, &
  554392749961429148_i8, 6318024328325654254_i8, 8712946810354967818_i8, 7913379504402361650_i8, &
 5106380571709109965_i8,-6762202060284373199_i8,-8910386985186826684_i8, 6694553116482970097_i8, &
 8170712449768789428_i8, 2731638158726855735_i8,-6834637561481830775_i8,-4636636134102307648_i8, &
 6863207448305608104_i8, 6933965713042368229_i8,-6454886987368326368_i8,-4526337477840746155_i8, &
-8357577197541364406_i8,-5612853153720059629_i8,-3001737136868235279_i8, 4925755768288427504_i8, &
 -203879769655943560_i8,  113245768953179485_i8,-8308870872085686794_i8, 2768066646992373011_i8, &
-7456693957782858359_i8,-6937948982872279752_i8, 3559998835776791247_i8,-8320065675001095663_i8, &
-8103667490543421028_i8, -296941349679964307_i8,-3810642293488697842_i8, -612018411815384438_i8/
data (mplog2con(i), i =   200,   399) / &
-8105387902634631930_i8,-1009125590875558032_i8, 7705737584272930391_i8,-3730623867343263345_i8, &
-5707429990998479100_i8,  991660500120474283_i8,-2765273063433043732_i8, -329187250272554216_i8, &
 4338570192167150373_i8, -913053121521904370_i8,-2877926411789332247_i8,-9147141886313824269_i8, &
-5561976884094616793_i8, 4420129821069921976_i8, 8856286571483211419_i8,-1451790901555361656_i8, &
 1381953771294821922_i8, 5259564605519747671_i8,  666268858244222547_i8, 8915499662522919559_i8, &
-5296915415011502918_i8, 4102828054804556366_i8, 6107559731065201443_i8, 5575872589336276302_i8, &
-3708826977898306741_i8, 6444128942485842768_i8, 9138825493114687895_i8,-5371058485686415297_i8, &
-3647172363462725329_i8, 3591998972724484856_i8,  326563753998058331_i8,-3956280886071822894_i8, &
-6075774860660976580_i8,-7038518034381967733_i8,-4757488533657634979_i8, 4062583897749930607_i8, &
 6296276281729986943_i8,-4267566666935948074_i8, 4625263856095657328_i8, 1525185082560689067_i8, &
 -906638957095185095_i8, 3239954264664349018_i8,-7897957571667386735_i8, 6235733137813852224_i8, &
-4689909522878852730_i8, 4387702124205664181_i8,-7834981904543776697_i8, 3267163420273927567_i8, &
 5398725129205914676_i8,  425157172555895045_i8, 1816695015263675363_i8,  -83697787984678058_i8, &
-6684738821343620498_i8, 4811642207417302950_i8,-7825899036983005730_i8, 5528437019525552739_i8, &
 3215292685273706616_i8,-6454484679167303732_i8,-3029266035939347336_i8, 7246143300819078343_i8, &
 7386002715769834870_i8,  158996749253971083_i8, 2975174738604669650_i8, 2355450335182478251_i8, &
-3457735766432143267_i8, 1721364756441090930_i8, 2844713143628563230_i8,-3684706933552061111_i8, &
 -252446038403025529_i8, 6846795062307186608_i8,-7708927620579218753_i8, 6890259950835015712_i8, &
 2007058470366896818_i8,-8398221365716113855_i8, 1786502448889289806_i8,-3667636889348843808_i8, &
 6009665645517380547_i8, 2845358961444607480_i8,-5186937165599945756_i8, 2021846992797428473_i8, &
 4305392535247840417_i8, -682467785432915630_i8, 1791814150034111798_i8,-5797485436410820822_i8, &
-6819167930101707870_i8, -460266083821032344_i8, 5245871566504291862_i8,-7969345542126036597_i8, &
 1187684058977366305_i8, 6022788501276044662_i8, 8693512026694910114_i8, 1945271981569676565_i8, &
-8734286855615606398_i8,-1404312803710041362_i8, 7911213805864623401_i8, 7808938018908075248_i8, &
 7150068159129519609_i8, 3579240125979730446_i8,-7520592987279220137_i8,-8274196534803471662_i8, &
 4481607377482119119_i8,-3702612871031488626_i8,-8358838512832381484_i8, 6614906359633210474_i8, &
 6778114580224384165_i8,-3970310560482666976_i8,  916370034664529979_i8, 6189842112206066653_i8, &
 7310280056737863209_i8,-4803330298241317177_i8,-7884997479779237605_i8,-6831666017977324578_i8, &
-5597948346014901722_i8, 4859471887948192930_i8,-8965493732790197956_i8,-3959499831544585338_i8, &
-2654598401365318977_i8,-2709900805156746838_i8, 8044552004909144651_i8,-6397082328086098221_i8, &
-2368542688103372007_i8, 4362670420089919631_i8, 8925033131530445635_i8,-8314592195406492819_i8, &
-5458844307963951508_i8,-5821152255009538308_i8, 9059259116628742734_i8, 2078082125448432555_i8, &
 2090757102729127198_i8,-4545360872725611379_i8, 4195194459137480098_i8, 2313159646701049266_i8, &
-4439369465396461275_i8, -779698167298636840_i8,-7683644700746712803_i8,-9155174249708866126_i8, &
 1204839402708608309_i8,-2565146261740540773_i8, 2556239525776409433_i8,-2976965463866148821_i8, &
 3124117597036416207_i8,-5299963773124872063_i8,-6886156386794001788_i8,-7655793356352417072_i8, &
 8242565677835161061_i8,-8393493718696691657_i8,  583760285843184506_i8,-8897138469865258966_i8, &
 3840820076458958604_i8,-3020828689884008668_i8, 5772233300833038452_i8,-2824448622375308090_i8, &
-4468044977406851221_i8, 5688597705213945562_i8, 7371185409651191482_i8,-5646075979887630559_i8, &
 2260891300291435116_i8,  772604220487065805_i8, 2216710944622927639_i8, 3500242889071152813_i8, &
  856996388467861520_i8,  307957767143381314_i8, 8452895552006988069_i8,-4093178005320362620_i8, &
 8267798809549740178_i8,-3538207870392437982_i8, 9218012822630422298_i8, 1535739454088346165_i8, &
  999362952906159044_i8,-4273402000543466240_i8,-7693750443841090534_i8,-4162950596208996283_i8, &
-5224023742511317297_i8, -642675416457814910_i8,  457996777500745999_i8,-1287859681550893015_i8, &
  607477924825377650_i8,-4486388646878577639_i8,-2681011001254404172_i8,-8632568047424167600_i8, &
 2332274271962127751_i8,-4021405052083364009_i8, 6646713142143117600_i8,-6138848808110451667_i8, &
-4647614791050455012_i8,-5588653299524736827_i8,  563065323890303076_i8,   63327171560267318_i8, &
 5727495439946394133_i8, -197354483869520456_i8, 4772516627812239181_i8,-3166401413774548086_i8, &
-5037134681320273571_i8,-1780856118202038173_i8,-3318656224703669136_i8,-5182083638581380391_i8, &
 3872699037731236080_i8, 5153504219495613609_i8, 8705838367029329103_i8, 7635018357842745282_i8/
data (mplog2con(i), i =   400,   599) / &
-3588958798439011232_i8, 1675620819687347449_i8, 3865269352885946668_i8, -680879151639217144_i8, &
 -148253240681300276_i8, 7525027655326355335_i8, -272883685096799673_i8, 5707598814472929891_i8, &
-1811698682558454716_i8,-9033289149429954712_i8, 1503878092777165228_i8,-5333600006401344443_i8, &
 2167269418359678771_i8, -995541548638005317_i8,-6233284019073310967_i8,-9175185155679701982_i8, &
  872842448194885666_i8,-9126278981180827744_i8, 7650872576465541114_i8,-2528730156265398987_i8, &
-7823908626313538070_i8,-2970046460112869387_i8,-2560623788543632491_i8,-9181225746456141484_i8, &
 6129824046589421023_i8,-8532206181050827345_i8, 2011453504530617787_i8, 2185698254699251825_i8, &
-4357272022975692178_i8,-4114830061116597799_i8,-7819930609397405902_i8, 4706131445334502629_i8, &
 4510242839898249302_i8, 3458774634898115236_i8, 5567389806982018794_i8, 5286064385819867084_i8, &
 8797376135819055344_i8,-3857728266584516627_i8, 8504406409548993654_i8, 1770053281877689768_i8, &
  801341744415130817_i8,-4218275011296726590_i8, 2363680035446124429_i8,-7892213095570537232_i8, &
-6678417379657178051_i8, 6515666027571824002_i8, 2533829491421219434_i8, 4407309550220676821_i8, &
-5615222908706639349_i8,-5428432695015403934_i8, 2545867027825193169_i8, 8624516076467069648_i8, &
 4386836261583145663_i8, 1297416183031050318_i8,-3184022976977454218_i8,-1533115326153960192_i8, &
  525742626055397430_i8, 8070738880019241729_i8,-7493125923538707529_i8,-4056918187145959575_i8, &
-2707167062487721686_i8,-6033972343014966600_i8, 2925777340654958743_i8,  651550247647983787_i8, &
 1299467881320760025_i8,-2336187450033116344_i8,-7071284488919684679_i8,-1968100079447246505_i8, &
-6199115262293101045_i8, 5405179711580735742_i8, -683212644530687104_i8,-8681683518282862522_i8, &
-2236360760968828047_i8,-5746207256711389544_i8, 1724570962823170587_i8,-5480603394045385800_i8, &
 3780923230373655518_i8,  667004842083738810_i8, 2538929136174580692_i8,-1863828001953176891_i8, &
 7600992436576599945_i8,-8703176300588066428_i8, 6802175345545682397_i8,-4616848270264799672_i8, &
-8457454048750796365_i8,-1383953757984146055_i8,-6581616465620513012_i8,  939926514397363691_i8, &
 2892529374942301991_i8, 1687014888016729787_i8, 6917849249792410719_i8, 6869285193162801772_i8, &
 6693795990691444423_i8,-6914448880262133136_i8,-8287203519128385371_i8,-4127678546694920893_i8, &
-6435726234715767352_i8, 2041334080424560659_i8,   69995428382956318_i8, 7089588833041275240_i8, &
-1529906693230621350_i8, 5786842743864010075_i8, 3684232896902434169_i8, 6004984082829898985_i8, &
 6893186215895464584_i8,-2000707337797600237_i8, 1369972518361061672_i8,-5906296923091595884_i8, &
 1066357908499275153_i8,-1489871414994201040_i8, 2643607623664928554_i8,-5144879744116813239_i8, &
 7962926404689460381_i8,-1557807934118498555_i8, 2643356468608260834_i8,-1863460352111471536_i8, &
-7925616734793879312_i8,-6463150609392733805_i8, 8374544290591856513_i8,-6647257925089675331_i8, &
 8108542787459979591_i8,-2257341700376517508_i8,-7905190983725256308_i8,-8588471613041019766_i8, &
 2355106566693569024_i8,-3159987421691977506_i8, 1174885662270305076_i8, 5055858087536432887_i8, &
 2972010024917255702_i8,-1139453438176787613_i8,-7668210211346281711_i8, 1258151919487110216_i8, &
 4984865424005784585_i8,-4646177906742300219_i8,-2063212092988605675_i8, 7658528186514235781_i8, &
 1296350010453799130_i8,-3099786735685462017_i8,-2428786602675424781_i8, 2693450355318397679_i8, &
 -845330863633243049_i8, 9200370916557785165_i8, 6545411771302521271_i8, -720956667876155465_i8, &
-7044990878240858551_i8, 3611347589973673635_i8, -471012690186632662_i8,-2470938391015416890_i8, &
 -617909543611391296_i8, 2579517823424993582_i8,-6845489946912673947_i8, 1885996047130608486_i8, &
 3595352352530744491_i8, 2055409275302963032_i8, -477475056529695762_i8, 9128465078368495737_i8, &
 2586394448783021903_i8,-4825453126616847918_i8,-6034701486213184483_i8,-4915886578286783710_i8, &
 6025992163261501373_i8,-3030592866389839232_i8, 3961048231333435534_i8,-4874832700503725159_i8, &
 3610481416360056495_i8,  101166908355319953_i8,-2140387775454682155_i8,-2857622815321409193_i8, &
-8157474046595361415_i8, 8823545989959689345_i8, 1073184253202079552_i8,-3164558811879827183_i8, &
-3949154167930409884_i8,-4509408923975990322_i8,-5965484560305918535_i8, 6458509194156641244_i8, &
-6382511700132476222_i8,-5557258930301919377_i8, 5849814465807971186_i8, 5158932591227582295_i8, &
 3478825054263809138_i8, 5658513651848007422_i8,  599373306004217875_i8,-1238107162995296255_i8, &
 4516459376121740139_i8, 6829211624944269383_i8,-4976078855401558140_i8,-8095048474934997210_i8, &
-8876471446278027566_i8, 2126687634024233344_i8, 8551556008090478948_i8,-4081330304686389309_i8, &
 3430878468688198803_i8,-2439741568474879329_i8, 4607878464137661612_i8,-7342819626494619738_i8, &
 2892158437378618149_i8, 8132572589246162472_i8, 8913162883836695570_i8,-3697588540160285856_i8/
data (mplog2con(i), i =   600,   799) / &
 4125218160235280547_i8,  432010180941951031_i8,-8652196363947623673_i8,-7111242582328346968_i8, &
-6008529467014967947_i8, 1495880015827588740_i8, 3677815007250339901_i8, 5984945705016589520_i8, &
 1689409194738838953_i8, 5238947317907673704_i8,  406546536036587551_i8,-8550748802781292047_i8, &
-7778862273071246341_i8, 7248227001944291007_i8,  138491878449715119_i8, 6267100569282703669_i8, &
-3179885067774071113_i8, 4695938547634814504_i8,-1120627147743844376_i8,-3260327846834440147_i8, &
-1576839322800234747_i8,-2554916699775532911_i8,-6672802367494225786_i8, 1876228414158941843_i8, &
 2977351700162616542_i8,-2092953716836519191_i8,-3757172777141606656_i8, -834191248114744642_i8, &
-7092450201490554681_i8, 8043420763195952703_i8, -779337096222530792_i8, 6849886931156379526_i8, &
-2979598899184655424_i8, 3744913292728938113_i8,-3602478000199172767_i8, 2702158730524200555_i8, &
-6608942979271414109_i8,-6962252813330512766_i8,-5935261779141840953_i8, 3200370693858095107_i8, &
-9063802750210529150_i8,-5084980115314822920_i8, 8851967265258176160_i8,-6815802332428586953_i8, &
-9101540666586847259_i8, 6312063896917867753_i8,-6512981708102581125_i8,-4096842148302168259_i8, &
-6255734599008813536_i8,-8852259673010972925_i8,-3485468330761462407_i8,-5498810609535817046_i8, &
-2178450451558288485_i8,-3754953939776644012_i8,-5196000892299182863_i8, 2709499939484151496_i8, &
-7158080585813513034_i8,-3176615383031638013_i8,-1241988721631687228_i8, 2496504428802754253_i8, &
  862405555356429912_i8,-7513358347371605459_i8, 8121853028903359960_i8,  603077143729328846_i8, &
 5734579373097644300_i8,-3946578352058164090_i8,-3092841474115951423_i8,-9130346170173725637_i8, &
 5646545889326844297_i8,-1678613748067136545_i8, 8643730417110702114_i8, 2700078448277523777_i8, &
-5007086398190431235_i8,-2199649016451316436_i8, 3545002430502552086_i8,-7918082411233529434_i8, &
-6414970012629751596_i8,-2754813671141738316_i8,-2022820694501549945_i8, 2532248528818455077_i8, &
 3810411683108835143_i8, 4584666023757493944_i8, 8178521289318975504_i8, 6338170201160617692_i8, &
 5600292256105438007_i8,-1078102437779582883_i8, 6465336533801525469_i8, 4729697924883678552_i8, &
-2255223208964709576_i8,-6537912229021586844_i8,-6855173265786907861_i8,-5061526737939754460_i8, &
 1554263963219813500_i8, 6453480580508433579_i8,  477749473935923955_i8,-3150303527158562679_i8, &
 9070472321504065248_i8, 2249361267254278386_i8, -982956812950131680_i8,-1776634636524049959_i8, &
 4458679228944793407_i8, -166126833370410958_i8, 1580893819561049227_i8, 7286802796638053581_i8, &
-2507289642057755064_i8,  894571181738010927_i8, -120967214351919746_i8, 3360966793850012998_i8, &
-7869598833185709342_i8, 6535919247039498953_i8,-7526134912665799155_i8, 3087293834530971786_i8, &
-5913375588958638978_i8,-6374026621373044905_i8,-7110221712392696464_i8,-4629320049580625157_i8, &
-6568305256014010443_i8,-5277592370926272598_i8, 7582162189122650805_i8, 3271651659422198530_i8, &
  684232494794927706_i8,-2019351329541237392_i8,-6834621460224144922_i8, 5136449486048370069_i8, &
 4691210144833082170_i8, 5268495760865172443_i8,-5331442379794145231_i8,-4435301684895739672_i8, &
-1892978044556137567_i8, 2818748515253239107_i8, 9149870125858393819_i8,-2714061686377819624_i8, &
 4743000984143097188_i8, -311108301591806380_i8, 4046368223849089441_i8,-4536034782934305788_i8, &
 4739057561541155391_i8,-3884348034323758402_i8,-2827911437971101965_i8,-1393531636544214799_i8, &
 5774927215967842323_i8,   58082620243347720_i8,-3700190229665300338_i8, 6410041496304969248_i8, &
 4115321927365906011_i8,-8517928994089969695_i8,-4030305343827827198_i8,-5847683372018790233_i8, &
-3346540909881812310_i8, 5841240010588916369_i8,-3499718109671185668_i8, 5373731107271124591_i8, &
-1561060086776162125_i8,-2014321146662115206_i8, 7782050979936820337_i8, 1815236353331876049_i8, &
-6717210405771847568_i8, 5403371806583290112_i8, 3421630323716674609_i8, 3632284542889848122_i8, &
-2381438116897193564_i8, 2332972360854285127_i8,-7280298785812771558_i8, 6391286706528113682_i8, &
 4873566044172757315_i8,  224213766223873518_i8, 4535892039883486796_i8, 2614628775165693009_i8, &
-5894659593942631268_i8,-4839248483748317733_i8,-4956019010174181368_i8,-8256412645041002558_i8, &
-3170670168721666785_i8,-4189090540398242062_i8,-6838215678678843762_i8, 3823217374400957469_i8, &
  663887436479339473_i8,-3066006944778846348_i8,-4448995587868613205_i8,-3973044901966884033_i8, &
 8438214622396411406_i8, 6579409079754055309_i8, 8996506191979693385_i8,  536875327704000578_i8, &
-1030996497978705447_i8,-1177672098510379847_i8,-6986269569251465186_i8,-7641842879393117561_i8, &
 2495202744560918912_i8, 3744004852951583710_i8,-2477944135424003848_i8,-8668089396778366807_i8, &
 7007287299484740071_i8,-8222822427885980416_i8, 5602448038065858379_i8, 7387033032630957259_i8, &
  -84126510598599483_i8,-7417845562340086583_i8,  382114865072573712_i8, 1269796006985258046_i8/
data (mplog2con(i), i =   800,   999) / &
-8291638420180203727_i8,-8213630330558252681_i8, 1352174955583088416_i8,-9036053155579586071_i8, &
 8858522720970145299_i8, 8054105567259794788_i8,-4766484738485926712_i8,-7373715758538166892_i8, &
 4622236019313381047_i8,-5489326173520793268_i8, 6339924757529867690_i8,-1740197222507142271_i8, &
-5270345451253725191_i8,-6608384439262270613_i8, -927714167251243915_i8,-7844628438935260057_i8, &
 3143358252832159072_i8, 7899953940205320719_i8,-7724582871821973270_i8, 3764841188972559473_i8, &
 6952180709219585257_i8, 4899116018002949405_i8,-1176033965181454423_i8, -422762504673207213_i8, &
 9009096624041534995_i8,-1292136622328840810_i8,  829478748055447608_i8,  274825450789667221_i8, &
-6668904353978299393_i8,-7660742688501564158_i8,-1342287004881093712_i8,-1240455534322464197_i8, &
-6268369095896730103_i8, 1259043617139383463_i8,-3311705796546156604_i8,-6772297359311794064_i8, &
 7210281745954234967_i8, 6341012519962418911_i8, -410541634955095439_i8, 1958860922375759276_i8, &
-3776172962367026964_i8, 7651969766728645931_i8,-5427011159828636121_i8, 6424627701669073701_i8, &
  111793055226541176_i8,-5787550292944648257_i8,-6532607813367479621_i8, 3145982120559027785_i8, &
 8325733008406441304_i8, 6387679910183765878_i8,-4715309046949175311_i8, 7858878355627676194_i8, &
 7497217906534903095_i8, -412915295386700262_i8, 4358414938197046470_i8, 6353950612713301150_i8, &
-7469489271394783299_i8,-7186088653876292158_i8,-6546055432401733679_i8, 8972435517311546793_i8, &
  286013512796942591_i8, 2352853977600763931_i8, 4705342537898198482_i8, 8822220053628757486_i8, &
 -215218948675517734_i8,-8435560718582379641_i8,-7025799715347319802_i8,-2996325739412067779_i8, &
-4337470321204702637_i8, 1895058634477584646_i8,-6383297737272896546_i8,  879944797011425201_i8, &
-4307302849778391143_i8, 5085838375315936459_i8, 6162603097684837781_i8, 7806146840925904702_i8, &
-7648311628077764563_i8, 2479413979734036865_i8,-2105645650616424082_i8,-3962692724770356133_i8, &
 8445348022019456853_i8,-7083496280268426046_i8, 1558952605525153020_i8,-4510282305100126591_i8, &
 4470081460398569471_i8,-2485304896737245570_i8,-8636393235922957365_i8,-9118026973331523825_i8, &
 9172953617627920711_i8,-7282783077227736540_i8,-2368897603895494454_i8, 9142930657045629159_i8, &
   78503714409364455_i8, 6271621529523180250_i8, -717692230226675586_i8,-1216014335600445975_i8, &
 6524440464677125518_i8, 3754602282370956039_i8, 3127218706642568014_i8,-2494586043360263601_i8, &
-4054470945569021808_i8,-2956646441875915407_i8, 8970274883892468019_i8, 2857816201694705144_i8, &
-5756960553183605227_i8,-8918259654145817530_i8, 6566873223742094269_i8, 1128257384167672325_i8, &
-7835318200459381081_i8, 6513929359063850608_i8,-5661402340381691474_i8, 8633125979553774001_i8, &
-6026318770319429037_i8,  -96935651642577600_i8, 1463221191877863064_i8,-7557945024125053281_i8, &
-6577276440082481488_i8,-3766790220329292781_i8,-3066409922336478830_i8, 4853205709837468559_i8, &
-3266542819564882180_i8,-1255125306305779837_i8,-4974111066417806410_i8,-7457940194457450771_i8, &
-8464393781201112427_i8,-2089078927499925372_i8, 2126312375026411415_i8,-8850730052856712883_i8, &
 6526060948148440112_i8, 3782886268850496926_i8, 4616937463712423083_i8,-2352591081164476318_i8, &
-5679607903703198343_i8,-9170381949266153836_i8,-5805878411625792773_i8, 1888533448826022573_i8, &
 -499733892327726582_i8,-3936385699925707015_i8, -437149701873860406_i8, 7908467908886976714_i8, &
 7496286798650120630_i8, 7083903438220296811_i8, 8351280926043609319_i8,-4527978338500613461_i8, &
 3122446419593954965_i8,-8081357311618820479_i8, -947834916587424473_i8, 2006951244055174130_i8, &
 1919935605167611636_i8,-2968749725156296959_i8,-6047004610025409352_i8, 1348239583426777193_i8, &
-6642648963174006444_i8,-3358929935063887373_i8,-8906656730110669094_i8,-5225899719599650868_i8, &
-5941862145081560560_i8, 8062879900679745266_i8,-8586809413570261366_i8, 2363745270234817426_i8, &
 1508931925449069755_i8, 5123958331046668426_i8, 1081491877773245656_i8,-1074243131755086887_i8, &
 3732979913381928924_i8, 1534707341129152403_i8, 6042401607091599235_i8,-2645140104359620578_i8, &
-4742632212547372727_i8,  912248912980489244_i8, 6146010341962107392_i8, -356780668411715572_i8, &
-1266065301583942394_i8, 3913447253483908143_i8,-8540450184403469153_i8, 5956911102215554104_i8, &
  444478003528123916_i8, 4514934080037916381_i8, 7216354388686325020_i8,-4186809995144690464_i8, &
-4561668008097995782_i8,-8801323741640803059_i8, 1683981977765195224_i8,-1118300135477856434_i8, &
-8113192788118828770_i8,-3545613899590519907_i8, 6876852507673314734_i8, 7802240711941756352_i8, &
-7553432075852997310_i8,  770416509291317028_i8, 5131894646154344633_i8, 7044027212584627901_i8, &
 1544185093073130979_i8,-7703331979813555065_i8,-2926734646020512662_i8,-1211735606326511272_i8, &
 3082069754683924604_i8, 6283537028398873861_i8,   27272943683312140_i8, 7067101201094214402_i8/
data (mplog2con(i), i =  1000,  1046) / &
  414657537012126457_i8, 3954207892741588665_i8,  845294622150838770_i8, 4765234938047111433_i8, &
 6814547362189857733_i8, 7039123212900017103_i8, 2777133410944596354_i8,-8255290016179222699_i8, &
-6813220759821201671_i8, 4944993435491556494_i8,-7578178478228404069_i8, 6156621654544259124_i8, &
 8473700360670835694_i8, 5554677440240256317_i8, 6868188547772629387_i8,  544780923660251931_i8, &
-5894863524137505615_i8,-7683895806106960995_i8,  884968683061185836_i8,  526276848443620003_i8, &
 7682155296647843458_i8, 2695012071269245751_i8, 5483728532390938973_i8,-3689487796548710068_i8, &
-3944054643684160205_i8, 1677036114017882341_i8, 9020186540394984342_i8,-1272656748978701803_i8, &
 6993299640500441506_i8,  573305231163259792_i8,-2725355326869088826_i8, 7304734722601575330_i8, &
 -729681282989018552_i8, 8272698762445801674_i8, 2697551639276418891_i8,-5050052767348531141_i8, &
 1930876632637913214_i8, 4510014273271556293_i8, 2834799538024855589_i8,-1355954891893759676_i8, &
 6166926504001936144_i8,-1749518573578244968_i8,-8499111239825556949_i8, 4680158270178506285_i8, &
-3899075386890062161_i8,-5660435428506895957_i8,                   0_i8/
data (mppicon(i), i =     0,   199) / &
                1047_i8,               66624_i8,                   1_i8,                   2_i8, &
          6165518312_i8,-8456819222712525089_i8,-3428273595701779614_i8,-5361020200928304281_i8, &
-1836288268377627234_i8,-2571047826973989772_i8,-2779181538754912623_i8, 7936229830477879670_i8, &
 4893887697634903292_i8,-8449080830616534274_i8,-5718620743643745044_i8, -895682034495479287_i8, &
 1786628967396748250_i8, 8706224932727962381_i8,-3187362226765760613_i8, -112393304868584576_i8, &
-8053630310408408886_i8, 3722443368686407948_i8, 7373544539390166858_i8, 7438183898845641786_i8, &
 2541650470744803671_i8,  -20756897769696010_i8, 1912384838144107560_i8, 3295224982325372783_i8, &
-3914893088774743146_i8, 5085334389687963785_i8, 6431432950200772162_i8, 6468795659207375381_i8, &
 1436891682080442143_i8,  153595810326371771_i8, 2017148113206442573_i8,-2199057034544580871_i8, &
 6866654478171985294_i8, 9085230867106307190_i8,  627878078692801871_i8, 3437561997326922069_i8, &
 7721676027669376386_i8, 6336788960730185607_i8, 3376651121105486457_i8,  920463129200894182_i8, &
 6418982130212201650_i8, 9184576827737348494_i8,-4038736252632927860_i8,  541709569451535235_i8, &
-6597053772437758254_i8,  -66935706645538134_i8,-5925208740890059758_i8,-3482379886642647867_i8, &
-6821393946062733475_i8, 4915218993999205259_i8, 1492263353870029087_i8, -169117684844694602_i8, &
 6091379828155916004_i8, 4433969781777692801_i8,-2442428896104469715_i8, 1553877607688215166_i8, &
 5819617065824045121_i8, 4229118935742461493_i8,-3625631309739036577_i8, 4605253162400104100_i8, &
 5660835286905703720_i8, 5826435357785054802_i8,-2981334054119646106_i8,-2415673054597945127_i8, &
 -267562388154123007_i8, 2505602303466160575_i8, 5023661450287303876_i8, -120344872716102978_i8, &
-8603716294951246466_i8,-4204994229236927262_i8, 6215089426170793025_i8,-3674048156642636716_i8, &
-6029731185648538102_i8,-4836785907944753911_i8, 4089586844287103150_i8, 8931051611785418768_i8, &
 6726502791319537715_i8, 6416446039786647945_i8,-8678694177629946225_i8,  307700319875570677_i8, &
 1647256619205527334_i8,-4776134113426145206_i8, 2365014738222474297_i8,-2574922960006051343_i8, &
 5222658396514765713_i8,-1466107971624361317_i8, 5031004471079354489_i8,-4485772217723086714_i8, &
 4116875174715686626_i8, -331545533994306904_i8,-8337792896941965909_i8, 6747082353331694802_i8, &
  597005313697708504_i8, 3975365537508122529_i8,-5179797526544672553_i8, 5086696778550951740_i8, &
-7406208329780696769_i8,  691625821907279350_i8, 3180852363138049248_i8,  -92325164358157861_i8, &
-2423385661003432845_i8,-5985042269328073722_i8,-4014332939001811222_i8,-5985060528830154144_i8, &
-3141319727987534285_i8, 2333204291248682781_i8,-8850199643633662953_i8, 3798073097320525538_i8, &
 4983916851459586714_i8, 2349009596958465105_i8,-5037701845887397544_i8, 8854372332639896695_i8, &
  110384373948941353_i8,-2363993296580755901_i8, 5753926745440981636_i8,-5125293516851318060_i8, &
-1797377961351670175_i8, 7645581904017224377_i8,-8372077256067380514_i8, 7312354077274824638_i8, &
 3652795644451805103_i8,-8093502315852888889_i8, 5988552717812694078_i8, -663802367956301887_i8, &
 2701106472317284301_i8, 2861545521011146364_i8, 6913618184711715423_i8, 3100991398490663096_i8, &
-2668970603432486352_i8, 4647475341711059388_i8,-5670274796250762266_i8,  277735501560016962_i8, &
 5346707866219792304_i8,  470806735150270272_i8,  885663824531891218_i8,-2096407972081761289_i8, &
-8131431597294853948_i8, 6903262198528683022_i8, 8581295564683770957_i8,-5082095057992220049_i8, &
  858609591268240093_i8,-6298248140714067861_i8,-2814751277781850288_i8, 6783386583060250734_i8, &
 1093707772017311464_i8, -951283570420036029_i8,-9181157419163562779_i8,-8443124421796788492_i8, &
 1864309637264084102_i8,-5852249137984609757_i8, 7500293617595233796_i8, 8019972166570395338_i8, &
 7579620172435422731_i8, 8712492574544987494_i8, 8428304376845060823_i8, 2489113822392302556_i8, &
-4829764659280550362_i8,-3794763563353477390_i8,  700988707420170345_i8,  315571363849156097_i8, &
 9101556926288636561_i8, 6289247010657968903_i8,   53284624295364591_i8,-1226445861814327157_i8, &
 -671909484292381873_i8,-4573660997753653305_i8, 2502622114857259819_i8,-1474914359842109031_i8, &
-4026319734555414992_i8,-4437027499391980688_i8,-3395344076129949686_i8, 4102892652157484831_i8, &
 5361484041359198241_i8, 4099330392687842905_i8,-4430013622642147842_i8,-8628348753798187769_i8, &
-5552967046117872898_i8, 1870779158293521595_i8, 4338343646656152353_i8,-6111828231218461502_i8, &
-3652067493028833477_i8, 1213523608093474619_i8,  211898071623535297_i8,-5971047756172595596_i8, &
  481445653344249007_i8, 4449661926575898180_i8, -287251400744393565_i8, 8404922671053284618_i8, &
 6682528823627041098_i8, 1322404341221182594_i8, 3713536714328213483_i8, 1554341515018779611_i8, &
-4682284725357530520_i8, 8730676601631694744_i8, 8793369372837839276_i8, 7081502366464958030_i8/
data (mppicon(i), i =   200,   399) / &
-7112262264564112499_i8, 2553404202065275725_i8,  -70435156273549972_i8, 6588101054242415228_i8, &
-6824322281871266546_i8,-6217250815257473935_i8, 4921809573055205645_i8, 1938684500775731087_i8, &
 4187790499873268979_i8, 3558521111308710592_i8, 1237064209592705928_i8, -505678293204085343_i8, &
 4962068695997900249_i8, 2450068269549140863_i8,-8122656107362294471_i8, 1594075838334099101_i8, &
-7897895940145427353_i8, 8160410687221845699_i8,-4301742566328650008_i8,-9153484576755059627_i8, &
 8075806044628932529_i8, 1408557688588194562_i8,  752452276663977100_i8, 4311965759874649538_i8, &
 8733435165828303409_i8,-1978392367376284281_i8, 5360184115263293006_i8,-6078417423790723793_i8, &
-2085327098188941326_i8, 6554676333711385770_i8, 1689214100916115994_i8,-2146008013579060599_i8, &
-1195361464212410172_i8, 8277205678852259978_i8,-4805413314094490693_i8, 2951403863141056313_i8, &
 1805935593617528100_i8, 5927567241974659947_i8, 1913181304516361714_i8,-7344663890392178282_i8, &
-3500856133585115923_i8, 8790720738501117720_i8,-4194057374619802062_i8, 1620560074559734482_i8, &
  847183141748066163_i8, 5948915024524288264_i8,-6480085819003425928_i8,  319051968621391831_i8, &
-2120483438218052003_i8,-9050682478923134615_i8, 4011677375048115020_i8, 1676882353363402201_i8, &
-4356893086767428422_i8,-8321207959466215144_i8, 9018225911768006729_i8,-3600062377269962574_i8, &
 5989270780629425443_i8,  914494273310006830_i8,-6381540747246885633_i8, 5584645452747492638_i8, &
 8920741355698010446_i8,-3447679811016173070_i8, 2359477859106542734_i8,-4298627625303302638_i8, &
-6857786252831663808_i8,-1162674403674844044_i8,  750628996679440307_i8,-1252386888269219317_i8, &
-2111891011547954599_i8,-9035382841860108977_i8, -186743160355551886_i8, 8586009881683958774_i8, &
 4242766769152202036_i8,-6504061212146106490_i8, 4561000359139575341_i8, -752654724118327273_i8, &
 3348349077508659709_i8,-1216831104247317187_i8,-6030861565366322110_i8, 7297434346040720745_i8, &
 2182291054907170128_i8, 3700951411621254940_i8,-4671096786804779585_i8,-3431776565337050784_i8, &
-6459405899118068218_i8,-8060685998816480739_i8, 7762459750146302339_i8, 7235166779774902603_i8, &
-4276080259987383733_i8,-4260597925468470589_i8, 6527535789759766907_i8, 6315345394085122957_i8, &
-3270654851977442071_i8,-2785574771897907368_i8, 8033284950529195458_i8, 6675210584823161013_i8, &
-4472209384122032813_i8, 4504600609527607981_i8,-1770821404200816615_i8, 3797420650287124054_i8, &
 4522772375022322196_i8, 4733923932120890607_i8, 4915259850607086094_i8, 8187436856421889985_i8, &
 5652719874731041285_i8,-5396542698045884241_i8, 1410588530220059963_i8,-6704029286788808395_i8, &
 3988496095837724832_i8,-5468742318530692015_i8,-3022242841881847162_i8, 9133314925025465006_i8, &
-4347467930609581936_i8, 2409440792961266820_i8,-2940672486320555369_i8, 5980815146641406958_i8, &
 5978121900300606813_i8,-1206539291668713226_i8,-2444481463226976328_i8, 8304271522599701048_i8, &
-7464364593456450620_i8, 4377041107269558725_i8,-8832342225879252445_i8, 7373972228120942016_i8, &
 7189693788619480998_i8,   30035187557219733_i8, -529643865348375831_i8,-1449708417672705195_i8, &
-3205354172751426766_i8, 8883953860945115554_i8, 4332249180486541232_i8, 5058564300839731077_i8, &
 1521889553402510095_i8,-7104784331761436866_i8,-4187820083298361804_i8, 4422344716412633068_i8, &
 4277845443730058843_i8,-7111685576265550410_i8, 5972088492024726021_i8,-6760802922551191047_i8, &
  256601356001404760_i8,-3954306095091484602_i8,-2526359800245346094_i8, 7655585685195623054_i8, &
-3504518941541831652_i8,-6141914375343425869_i8, 5311382375301029738_i8, 2941617369450160293_i8, &
-3343583381090171890_i8, 7526277976589827857_i8,-8192517009951643329_i8,-7620524083617053849_i8, &
 4192221154117228727_i8,-1769358999626111937_i8, 4256529223580559837_i8,-4011547258955501513_i8, &
 1049229019728275701_i8,-8323658408593992498_i8,  368675678951900962_i8,-6404984489292076141_i8, &
-2346936846073295846_i8,-1910851228027617891_i8,-8181898449887661298_i8, 1643806787345520464_i8, &
-2277345562101523772_i8, 2307090737527898878_i8,-8217040366357759652_i8, 1136591842376152861_i8, &
 6664364521247663868_i8,-6633841579189493890_i8,-4418571832490810425_i8, 7429523760735972554_i8, &
 -906621794162668416_i8, 2440961347869622481_i8,-3401497457240316984_i8,-7042483076140566235_i8, &
-3812589839858142141_i8, 3120320712782119318_i8, -716743459169352114_i8,-8766457571842464895_i8, &
-2855014536954030361_i8,  313898478142771589_i8, 6147710368422031927_i8, 6704199313303082665_i8, &
-5211258587658602328_i8,-5627610447618903047_i8, 2532222454112205181_i8,-4568221135463244337_i8, &
 5773282450564754640_i8, 8940579561011376868_i8,  435197064006856068_i8, 1951664153477789113_i8, &
 7407533402896444877_i8,-4893100238468909113_i8, 9107040619598778313_i8,-5735032175586477488_i8, &
-8632758302186087421_i8, -300104498182855315_i8, 7911611775803422523_i8, 2607680569908667718_i8/
data (mppicon(i), i =   400,   599) / &
 7178222910220497280_i8,-7059110019407152971_i8,-8149153694663028707_i8,-6746471369732518524_i8, &
-6875818590393878512_i8,-6916976972881222794_i8, 4242519800218264154_i8,-8853566617497751934_i8, &
-1707745970877985583_i8,-5879015407124673894_i8,-8254419307730054142_i8,-3900941460010607324_i8, &
 2181825182662127091_i8, 7532585699389474453_i8,   61292393462721320_i8, 5110596368339410784_i8, &
 3604016958086063977_i8, -911417398541076883_i8, 7021664455031276829_i8,-2094446703810661948_i8, &
-6723241754431737098_i8,-2407642076386875471_i8,-2912195480385585874_i8, 6516000998960200578_i8, &
 6080376925405849212_i8, 5862481477511323729_i8, 7718028081592473835_i8, 7351744047643665571_i8, &
-1345457474672830075_i8,-7483347876488850791_i8,-4122691929168646269_i8,-2958017617457643685_i8, &
-5670470941832743306_i8,-4503310175174886080_i8, 3056560388459089079_i8, 1264734545529975040_i8, &
 6013701248786410784_i8, 8552673823014962235_i8,   62140919058111598_i8, 6921601631825950398_i8, &
 -312435181402710023_i8,-2096046739229168625_i8, 3515111037872547884_i8, -817056558398712711_i8, &
 2400098411884307747_i8, 7867157726595041603_i8,-1572991170583296217_i8,-2849384189818780997_i8, &
  306343029769302778_i8, 5187485224675616556_i8, 5667766324627854426_i8, 2038668814956968910_i8, &
 8298846112572354467_i8,-2861959219671945140_i8,-4671579132803363140_i8,-5233016698988875205_i8, &
-3954757467146664026_i8,-7641875261815828850_i8, 1545044503958508494_i8,-6783273208896522444_i8, &
 6881288826918204143_i8, 4311851022305803112_i8, 1595000685352335953_i8, 5016941098145463608_i8, &
-2054358447899017898_i8,-6568311615898450686_i8, 8632381104456364937_i8,  379198645942819145_i8, &
 7237719895548188392_i8,-4518314519337377878_i8,-7488165765497851701_i8, 8440746837238066583_i8, &
 4676139100616822604_i8, -344673826333560510_i8, 8550705479174945042_i8, 4271811079480045286_i8, &
 5514356911326964266_i8,-5638531009034197570_i8,-2430917909085747538_i8,-4559272385166447559_i8, &
-6775653829546989458_i8, 6074052029533126843_i8,-2986893543689486813_i8, 5479358076348666747_i8, &
-7077004346926842457_i8, 2702459954701984334_i8, 6108475542471320563_i8,-9157222475524350769_i8, &
-6335892045820888137_i8,-7921669331733857327_i8, 8450183646746277199_i8,-7690189081127636894_i8, &
-5904052339537709791_i8,-8529490006979748675_i8, 4497211903573515825_i8, 2761810677835127302_i8, &
-6157066881645530508_i8, 5771785081805127522_i8, 2396515086827648111_i8,  567116955572803596_i8, &
 7182298144471221033_i8, 3354635541813986334_i8,-7396712146843561735_i8,-2905650638449539799_i8, &
 8971928579339073619_i8,-8418675144249780556_i8,-5122084827056456514_i8, 6976999741567611552_i8, &
 6899946389768405548_i8, 7094045170721038308_i8,-4607019987655012021_i8, 3174793362954472203_i8, &
 5314880012658093827_i8, 4647182233518938666_i8,-2636497403327500616_i8,-5013733511225739513_i8, &
-9163872453532246496_i8,-5673318080414794875_i8,-6739556426361986667_i8,  563696902892767854_i8, &
 4163070276645381640_i8,-8089245546243077444_i8, 5994246799245703520_i8,-7227786096326478537_i8, &
-5904585521450938786_i8,-3034309075925934919_i8,-1309535611436271466_i8, 1135550644409743783_i8, &
 7220745860720048040_i8,   31765686396844158_i8,-8767892099426229597_i8, 2209787938567252639_i8, &
 2410269760152019830_i8,-7067299616989030376_i8, 3354627737071498141_i8,-3590794591482025092_i8, &
-3115277424807364364_i8,-5930409619328489718_i8,-7186449499592523640_i8, 3371348909378991293_i8, &
-5590492163001941056_i8,-7964488390391587098_i8, 4157299572380435714_i8, 1374763398141678981_i8, &
 4009778876076937844_i8, 6594832972958178547_i8,-6107971429765121299_i8,-1951732867005205696_i8, &
 9027743448740699528_i8, 6999707289019926694_i8,-4213631637385443519_i8, 8329581731662241691_i8, &
 8742391315363706404_i8,-5079255735737975737_i8, 4020984268693326795_i8, 3562237664144755894_i8, &
-8736247633709314781_i8, -799374593459716985_i8, 2866511805515359415_i8,-3231851497903998375_i8, &
-5171509495407954226_i8,  303029911961004304_i8, 7903889740808673923_i8,-1105043175133763020_i8, &
 9131440600286865210_i8,-8942883200088865463_i8, 3451385188867227402_i8,-4848891909131316889_i8, &
 -150986664091750706_i8,-2054120408186336557_i8,   58107861068434841_i8,-5460975518893295986_i8, &
-4133141370228183194_i8,-5494316293664658767_i8, 8648936721052988541_i8,-3761435403647193422_i8, &
 7503575839128395346_i8, 3372807215052310895_i8, 1748900978350149623_i8,-9203519998841288194_i8, &
 2004047823041473248_i8, 4732764158139541522_i8, 4065625706697461383_i8,  951545514045041633_i8, &
 5769166931796768947_i8, -136086981857452201_i8, 2090659115299161301_i8,-6075182419339405092_i8, &
 -817692397272311961_i8,-2064473081248801839_i8, 6681850540933587246_i8, 5732311092041692021_i8, &
 -619074938680737839_i8, 3689715143906506990_i8,-7570623578843503792_i8, 6204614156910866987_i8, &
-5987938664442662857_i8, 1900883527671597145_i8, 2930578937154858121_i8,-7910690554935707232_i8/
data (mppicon(i), i =   600,   799) / &
-6184083442426556591_i8,-7761826856305430644_i8, 8835680048214154995_i8,-8221507930897760668_i8, &
-3208245375147428061_i8, 3094839745498014871_i8,-3885377480231307650_i8, 4671795359774576430_i8, &
 6723019142189121405_i8, 9036219484560899270_i8,-8732519917966276483_i8,-6500446079961628214_i8, &
 8141073836170024424_i8,-9157972770605679569_i8,  378684402319563630_i8, 9071801684156798883_i8, &
 2168413283401160725_i8, 4482587454939122570_i8, -417443731569977869_i8,-7931917292053135706_i8, &
 4038157785908013433_i8,-2975281640510440109_i8,  569645377594895910_i8, 8391278909687024458_i8, &
 7328881678642801055_i8,-3802113449739492652_i8, -404128425145715227_i8, 7404614514019121508_i8, &
 6933619578797564288_i8,-8088152831086919018_i8, 8199924576207289846_i8, 5974699326097938618_i8, &
-8500077285912703304_i8, 7203865306817173237_i8, 2373423867151145619_i8,-6248884212636797911_i8, &
-5754913480917840963_i8,-7423089728336839800_i8, 2917969153208570982_i8, 3108972181780412609_i8, &
-8480719041517940332_i8, 8456848086767244145_i8, 1496319033017071519_i8, 8190039690109415602_i8, &
 1572366275284638622_i8, 7826038372820687789_i8,-1305191930272390127_i8, 8469941725652070686_i8, &
-5385069683642475323_i8,-5413175225008314641_i8,-2941947974170128944_i8,-1517539567028057274_i8, &
 1048902816761822579_i8,-7366834955741560776_i8, -727739751941480316_i8,  975785730568729101_i8, &
 2014641726164587441_i8, 2927697332526138575_i8,  546127252314159550_i8, 8507122901616116721_i8, &
 4275346914766956909_i8, 5093666755350867519_i8, 2429934543765202798_i8, 1034845566676541193_i8, &
-7223359276438323102_i8,-4972220930117449891_i8, 3383042890231918007_i8,-3102778498021816947_i8, &
-8900898789321196904_i8,    6779771437915992_i8, 8936793720682799544_i8, 8131270024790409645_i8, &
-1819978674128035440_i8,-6340877574436441079_i8,-7780998047147646722_i8,-6307093749030494252_i8, &
 8587791235107668415_i8,-1701871909951882150_i8,  481409377659087159_i8, 1343875927877861252_i8, &
 -426003853847285853_i8, 6452323907479048588_i8,-5917793210798016766_i8,  318093739519978087_i8, &
 3333485301818491252_i8, 2537027854995077011_i8,-7954598962589264420_i8, 2385363668957652344_i8, &
 6825989841562859489_i8, 3250891486794823278_i8,-7720930693841362019_i8,-4819630269698773136_i8, &
 6023068776427650920_i8, 1536167992425319320_i8,-2456689477545219191_i8, 7791245367621719959_i8, &
 2364560009561877212_i8, 2148616699930066739_i8, 8394534684386527212_i8,-7485511453969950701_i8, &
-6381846868162383839_i8,-1175445678483492609_i8,-7409589258582644201_i8,-5313338145173210486_i8, &
 5841315597107102945_i8,-8121837899437543182_i8,  475908240764484478_i8,-4492218610109982508_i8, &
 1910811081167901817_i8,-4279172591919580089_i8, 6489875534554237646_i8, 6920265325485984843_i8, &
-3616870244548323746_i8, 2226219056611915194_i8,-1241643425383126199_i8, 2892564141871290280_i8, &
-2765518038962348185_i8,-1347064589417448638_i8, 4344358947239509992_i8,-3901958895002437119_i8, &
 8187215661099502349_i8, 2758164858097343171_i8,-1583939854541326466_i8, 1052676465360781133_i8, &
-9038204587574837283_i8,-5699446847663267001_i8, 1518391317973914174_i8, 6421924267619990908_i8, &
 3748294587432428863_i8, 8618907973418794442_i8,-6814886852408999066_i8, 5677071935162265160_i8, &
 6541730762529416376_i8,-6063652745171935163_i8,-4358168115558200153_i8, 4034726262996523782_i8, &
  675221141971445528_i8, 8984452986881461593_i8,-3704258543920680908_i8,-3453734896271221883_i8, &
  143678113149159363_i8,-7912748885384896073_i8,-1913953622183273656_i8, 2319007835616840504_i8, &
 4575158045294316508_i8, 6322244117183745119_i8,-1618319945025959554_i8, 3686840990640404172_i8, &
-3068611681136056682_i8,  -28452689656044206_i8,-3074605534022671519_i8,-3364165096680839863_i8, &
  -89300875356427035_i8,-7345236860637149122_i8,-8170727516486053684_i8,-8527326697048447508_i8, &
-4075055359065373163_i8, 8903183164709835682_i8,-8628994134998458002_i8, 3719455311906130576_i8, &
-6146419948575139845_i8, 3270519334010434989_i8,-7795731329812665501_i8, 1874535560222630779_i8, &
-2722701846034376128_i8,  183277278534146942_i8,-8497133571515807107_i8, 8541448301041582758_i8, &
 2718707344102870608_i8, 6911648238369169729_i8, 8065668184963769825_i8,-2576842436778652719_i8, &
 1397662929115767915_i8,-8860740057395174896_i8,-4067175374733635247_i8,-8003471385588393877_i8, &
 3819625451115527450_i8,-1207779662845411302_i8, 1172422708546286909_i8, -174785484489602483_i8, &
 -410013821019598787_i8,-5064042922066777219_i8,  382674550446100306_i8, 1101761399230267336_i8, &
 3562643182800834102_i8, 6473914149861183696_i8, 8564992122474029619_i8, 4572659683261130674_i8, &
 2851093624418028833_i8,-7601747420782595401_i8, 7663554172641542576_i8,-5027153987490126387_i8, &
-6232453976856587225_i8, 1162347248216820891_i8,-2362263527340925672_i8, 8473517460564774646_i8, &
 5538508507305009040_i8,-8688713550407934952_i8, 1589950208883916154_i8, 4978918903638950784_i8/
data (mppicon(i), i =   800,   999) / &
 4780271663139148327_i8,-7935023123124671327_i8,-2322369558667403996_i8,-4674137281639879256_i8, &
 3735921143964715409_i8, -499105872046172012_i8, 8504940589242995569_i8, 6436715647886116929_i8, &
 3589576782583082733_i8,-5270597199951899660_i8, 1259803576782990074_i8,-3421584231639317256_i8, &
-2931133938441572872_i8,-4644834814462062820_i8, 1601870501015306234_i8, 2591349040825175114_i8, &
-5517821335745885163_i8,-1810182068862152283_i8, 6196215492240776344_i8,-6505528928074584410_i8, &
 4867654569258747893_i8,-4288723342244313952_i8, 4471478660669950813_i8, 7313254668175368042_i8, &
-1813540223878436826_i8,-3717797953817514435_i8, 1160264646952398124_i8,-6338576308043862316_i8, &
-7412142496115885006_i8,-1789381322565951205_i8, 4301819104976210729_i8, 8459914605901821829_i8, &
-1342962038923843442_i8,-9165599814715385613_i8,  356675027507638117_i8, 4266969183069652292_i8, &
  380674608157808732_i8,-3838228605291492383_i8,-4921403858417359538_i8, 6437341931590313472_i8, &
 3516387151998293673_i8,-1414185309035085878_i8,-5120855124035571168_i8,-4977744656299145255_i8, &
 1479689498060440749_i8, 5066067461157199448_i8, 4376887139125119695_i8, 2990125259518282621_i8, &
-5655039339718460770_i8, 5445751754383961306_i8,-2301442258675060215_i8,-8477613782376790205_i8, &
-2465727637540093506_i8, 7026626430755637932_i8,-6793449843835905044_i8,-6363955936888533221_i8, &
 8981296665172147966_i8,-3529619178413020862_i8,-4535874981771808294_i8, 6947679790799537766_i8, &
 6663073619390518165_i8, 6063252475552381239_i8,-8887762258154131180_i8, 3985913053461917317_i8, &
-4915953794736097726_i8,-7439294738553294604_i8, 4260047969411221374_i8,-1213747934280884381_i8, &
-2407717408195070331_i8, 1443042463754302305_i8,-7690850156591522743_i8, 3234406437647273931_i8, &
 -601620018049531388_i8, 6169487409997931115_i8,-3806099532506865890_i8, 2004246149334204719_i8, &
 6022758345169661506_i8,-3701907318555824948_i8, 8686937245748986763_i8,-4957845471816235120_i8, &
-1562440857335627581_i8, 3615648936670066537_i8, 5672698660181292727_i8,-6553702980284231232_i8, &
 8386904265379695613_i8,-8547587355999844241_i8,-1476268879588270804_i8, 8937120511058521343_i8, &
 3174675508278592259_i8, 2566859626834672814_i8,-3494264415145448553_i8,-5915736764578528819_i8, &
 6494135004533635233_i8, 5703182228362271784_i8,-9053894621030073358_i8,-7430734388510870761_i8, &
 5996340738141207241_i8, 6001976938276149104_i8,-6308233551074948035_i8, 6549352291948679157_i8, &
-8082512009065617575_i8, 7500257890532724367_i8, 5065846620764132106_i8,-3055388215425079368_i8, &
-4959972697424099841_i8, 7438706533472103577_i8,-1487408695407413281_i8, 3953388940761123208_i8, &
-7863676124584424879_i8, 4768909473997734362_i8, 1507592445337527272_i8,-4626039817629510247_i8, &
 7897300851900710509_i8, -241581281253296571_i8,  157234480653204039_i8,  781419742571896064_i8, &
 8467846813433917881_i8,-8731283320126256571_i8, 7841272119379176018_i8, 4932011525869982352_i8, &
 6974247187197031402_i8,-4026403985253896591_i8,-7048044483256609569_i8,-7685141769063241302_i8, &
-3956115786824520121_i8,-8603563936980256725_i8, 4614293558707121367_i8, 3859662898394013586_i8, &
 -363828659107159448_i8,-5632577352892985997_i8, -456191663460745567_i8, 7274189455706457373_i8, &
 5014732456614780353_i8,-2364091972199945674_i8, 7866121656090294317_i8,  444516014204549286_i8, &
 8748298368127327546_i8, -388070981320538136_i8, 5461679451765179869_i8, 3779642020548194411_i8, &
 1435337285752320199_i8, 2459578943964150791_i8,-2018253927572272423_i8, 2562291777950016813_i8, &
 3757044925203597688_i8, 4227582198408344936_i8, 2699616139681735782_i8, 8367591073790052333_i8, &
 4307748803221246720_i8,-2828607116368334406_i8, 4068857912317108108_i8, 8404722335361197540_i8, &
-1831565239347441319_i8, 1350848282291893462_i8,  305839494018916590_i8, 4071228600131257448_i8, &
-2713759709207030222_i8,-1505947537061456548_i8, -769928354993291280_i8,  477897831538350710_i8, &
-6370599031875575000_i8, 1498677032303736800_i8,-3706623577160097320_i8, 5464000709718529194_i8, &
 1089103341458840261_i8, 2569719744895420606_i8, 6478368139494549747_i8,-5356961175142982498_i8, &
-3071894547469955966_i8, -827862099866353930_i8,-1138590376342184701_i8, 6450221200295301868_i8, &
 8050452619988882111_i8, 3684033904258821954_i8,-2630361358313708213_i8, 4958019789371259675_i8, &
-2720495319038356243_i8, 1699871023477459224_i8,-5734678895712020431_i8,-1883850243516137042_i8, &
 -504521876838657266_i8,-3930201606620301379_i8,-4479713070651390242_i8, 3946273353039114278_i8, &
 5617173773515130002_i8,-8719048195618455409_i8,-7803354313395282495_i8,-3456916063685420375_i8, &
-5180303446922737636_i8, 2261134052400748463_i8, 2538800413216073709_i8,-7371664371311656030_i8, &
 2917304821422473309_i8, 3354895935799741094_i8,-2613280912823120135_i8, 2703261255863651560_i8, &
 1915270317141724122_i8,-7367001579620867524_i8,-8614935215489787098_i8, 1905651643148920535_i8/
data (mppicon(i), i =  1000,  1046) / &
 5441141238023653377_i8, 4889602962105372814_i8,  640161647614602033_i8, 8577537326653720290_i8, &
-4908616454374335124_i8, 5917495817861275660_i8,-2849087020267443612_i8,-1067359679337068444_i8, &
-3538753821082456469_i8, 2201298008914878877_i8,-6055742203936295977_i8,-5505914952732252985_i8, &
-8436806331888432003_i8,-1370355407887012086_i8,-6317105880250926492_i8,-5966399736661378509_i8, &
 1545454141666149421_i8, 1572361106993317136_i8, 4149303432552213221_i8,-2437630513363020008_i8, &
-5348765695191788855_i8,-7266694737971142001_i8,-2045066149513755133_i8, 3643515754058796603_i8, &
-1048094028264365700_i8, 7425368496004700164_i8,-7001644933747141011_i8, 2045464732017971899_i8, &
-8978667873486262890_i8, 7572309818504171359_i8,-7432548837780761702_i8,-4467433697928036603_i8, &
 5271575865889938237_i8,-5863928532294754330_i8,-1281155366686974043_i8,  864511594326308845_i8, &
 -843225458941629077_i8,-1979976941098336570_i8, 5755940542857986629_i8, 3470879405153129527_i8, &
-1183011067081899237_i8, 5857503583518590173_i8,  147421033984662306_i8, 2955010104097229940_i8, &
-4267615245585081135_i8,-3958705157555305932_i8,                   0_i8/
data (mpegammacon(i), i =     0,   199) / &
                1047_i8,               66624_i8,                   1_i8,                   0_i8, &
          6165501544_i8, 1588769180060634176_i8,-2401208990976544179_i8, 2081985115405516166_i8, &
-6687049115464912066_i8,-4543228450433696873_i8, 4759561946197033827_i8,-3910802314950025266_i8, &
-1444868037689947281_i8, 6107515415443701516_i8,-7262671249087247869_i8, 8495894361646599917_i8, &
-1288902777663830997_i8,-7521577467331461644_i8,-4318080325867949289_i8, 6581850987039703660_i8, &
-1359962871944958087_i8,   77969605358340148_i8,-2873844069032440297_i8,-6980752342872007889_i8, &
-5690341281037120146_i8,-8785746767066096643_i8,  227463734076241797_i8,  907675393488129327_i8, &
   68191874096058573_i8, 3971936308147655837_i8, 3352078310581282114_i8, 3570064567511163087_i8, &
-7338191343170082211_i8,-6893335952150316793_i8, 4746314749506292651_i8,-6999347438425148061_i8, &
 6816763564298045056_i8,-8735388346501865830_i8, 1169612708920635561_i8,  838442232759217894_i8, &
 1799318498570330971_i8,-4375208433491426280_i8,-5190984666643515111_i8, -658135470566586903_i8, &
 6776490632849471440_i8,-1092552737446696395_i8,-8051417393221586241_i8,-8471107020030157297_i8, &
 2932310034612852592_i8, 8492017463448224886_i8,-7744201628340139250_i8,-2758365909525030195_i8, &
  938228565147365083_i8, 8519949591948652558_i8, 6510889766543673375_i8,-2611971813306804332_i8, &
 6120270884472616223_i8, 1129695154453398683_i8, 4887904834250423278_i8,-8864668561035793167_i8, &
 3586250458720113760_i8,-1489265590086165026_i8,-6317667398041419955_i8, 4899867122326778772_i8, &
-4465115938633447213_i8,-4158773169205996773_i8,  770743774835999435_i8, 2965287666007356878_i8, &
-7234347495867581750_i8, 2465947680933262417_i8,-2219228536255972646_i8, 7344929453313682306_i8, &
-6909945782385115704_i8,  163396327964899596_i8, 8649085333723897316_i8, 2737269023723043007_i8, &
 2535753414788746944_i8, 2615162254855487158_i8, 1798732939924557869_i8, 5954352225745074995_i8, &
  912520801053896096_i8, 4445796988208237091_i8, 2065380914824110217_i8, 6318590723625137001_i8, &
-4867880201241874589_i8,-2013662357283349052_i8,-3814328271651287164_i8, 4652616649582050228_i8, &
 3015380970648783673_i8, 8378061473397016488_i8,-7870056692732885963_i8,-1424510123342144914_i8, &
 -310721878821544150_i8, 6870992558504594419_i8, -899333016779562830_i8,-6383514261138120644_i8, &
 5370407248439504291_i8,-8819313088317566794_i8,-4782283714057428366_i8, 6478583407528262634_i8, &
 6424881490337221859_i8,-3060728722747977316_i8,-7790331885530892588_i8, 1050971454489364088_i8, &
 5750674157712548848_i8, 1997676662665403641_i8, 6196194984062133579_i8, 4283300325372149272_i8, &
-2876516317805538993_i8,  195559025185371628_i8, 8132723800565111495_i8, 1042657276402372242_i8, &
 4967315314867053595_i8, 6147245881988542215_i8,-1739259264147913394_i8, 2376074824133818464_i8, &
 8180235455275288947_i8, 5593705216257811500_i8,-9174812745783232947_i8,-5531821402080265705_i8, &
 6920220886707292997_i8,-5341000341109295101_i8, 3167971186695121678_i8,-9199202244013023135_i8, &
 8499966210653383869_i8, -224938098467568896_i8,-6472600236703771584_i8, 6081882263460549446_i8, &
 6699561077747021742_i8, 2836105779108995148_i8, 3892486105712796998_i8, 2985276693282612689_i8, &
 5251604532433089530_i8,-6291851672410715053_i8,-5443740579368557764_i8,-6320526682482778514_i8, &
 2437629632843917125_i8, 8205559557561790997_i8,-2639415704548984022_i8, 7700465023615412424_i8, &
-6308600756691453341_i8, 5608729927697265019_i8, 4821418157111522099_i8, -417415632016146068_i8, &
 -695204142367922785_i8, 5001267422137013324_i8, 2715828507260980824_i8,-6706986748216300224_i8, &
 1772090799743535234_i8, 9087778707600113524_i8,-2780015625312864564_i8,-5171631491778930815_i8, &
 1967522873629255319_i8, 6985872572260060389_i8, -112664820599659496_i8, -870773167901892782_i8, &
 4814311346221008447_i8,-6696388749024483547_i8, 9133001210965020154_i8,-4252355646680437119_i8, &
 2080503418416531847_i8,  729002796758321584_i8, 9050695716336326168_i8,-3067539297133456725_i8, &
 3243263504346920551_i8,-3213720454502000161_i8, 3250858972774527478_i8, 7082748010558278651_i8, &
 8959911393952810590_i8, -757561929170482430_i8,  192992695225259899_i8,-6064965914179456509_i8, &
 2025433200445846077_i8,-1417224039911632666_i8,  -23645228817348071_i8, 4297946520765314172_i8, &
-3596096644640335390_i8, 3833826028161079066_i8,-2189026387094886182_i8,-6525020775097458053_i8, &
-6165639805278993596_i8,-1207623727084485408_i8,   22974657698542834_i8, 2408959953465239053_i8, &
 5449078522619226155_i8,-8709191748509930402_i8, 2721937761002459285_i8, -441355563352367039_i8, &
-5845518712059691627_i8,-6745028674479388101_i8,-1450187744292850223_i8, 3473572766507585076_i8, &
-1158014884972904761_i8, 7000862578406184304_i8,-6113003987073993927_i8,-1611571099977417397_i8, &
-3114619507238450768_i8,  901729005585554646_i8, 8923769406827117836_i8,-6391890938742241320_i8/
data (mpegammacon(i), i =   200,   399) / &
 6553483144921555303_i8,-6355331708153971866_i8,-6320347178268646954_i8,-2410232606904867704_i8, &
-2458923897618177362_i8, -479450648589077753_i8, 7726272176818791625_i8, 1007408809247974078_i8, &
 7699988052756247097_i8,-4902302582894801069_i8,-1940646098214299966_i8, 8150411980919730589_i8, &
-5923795205983567921_i8, 5078444512626244882_i8, 6476705975657406083_i8,-4197171362413227306_i8, &
-8053532177908491344_i8, 8344178312772245953_i8,-6357706085050316106_i8, 1153695028620676952_i8, &
  719161919104468463_i8, 5487135879545257619_i8, 4883222765400632988_i8, 4591507462855154029_i8, &
 2429550760268382125_i8,-1940971438267818050_i8, 4460717291624899577_i8, 3619305507291828372_i8, &
 4032436395853600222_i8,-8644439976392815613_i8, 1094630007129640639_i8,-4949034129125938593_i8, &
 7486080945006843697_i8, 1517695823741018798_i8, -138153537736961843_i8,-8158270325293542252_i8, &
-2946404819841569730_i8, 2729708818999245190_i8,-3746449775045482823_i8,-5448350569944960798_i8, &
-6043536662281977683_i8, 8100172877668902795_i8, 3460423974730125006_i8, 3321160915562721036_i8, &
 3785365881072656393_i8,-4076347028349480514_i8, 5412239566143000187_i8, 9075430344739372387_i8, &
-1414792008195850699_i8, 6467566390599971647_i8,-4694389199379138104_i8,-7458477084617388417_i8, &
 1726769312964925105_i8, -123127622204786919_i8, 8359213448345014942_i8, 5510852240965734913_i8, &
 3851099524569281558_i8,  941179685960890573_i8,-1494926869499182122_i8,-4333923174779268410_i8, &
-2484073329516290796_i8, 5462409309209078724_i8, 1806527585771315206_i8, 5573191101596388112_i8, &
  -55961077906195607_i8,-1644262155772035528_i8,-1342161000783979432_i8, 8303517445180859338_i8, &
-7323777272368708817_i8,-3142339185495667953_i8,-1539034915272116311_i8,-8341392815058424500_i8, &
-6954802796605070087_i8, 4371592256002858362_i8, 1551590151856657048_i8,-6848591789193658354_i8, &
 6838781314336316559_i8, 5453552955577079247_i8, -430168857946458770_i8,-5326043933352732392_i8, &
-2018255025627840157_i8, 4726064235175997343_i8,-5785331993313988329_i8,  207132748004201199_i8, &
 3574865369569120321_i8,-1552918478216420334_i8,-5565167017597664698_i8, 7686365326353584675_i8, &
-1385346031275473835_i8,-1491371528433334086_i8,-5316537033799104058_i8,-8489046332878457318_i8, &
 6955104769705825380_i8,-5756784357400819829_i8, 3215199322393171978_i8,-2058888721588995205_i8, &
 2528969213865698651_i8,-2403030001792728785_i8, 5846524748817115245_i8,-6264736707054189825_i8, &
-4250786385145627447_i8, 2714045649197572731_i8, 7404949739311859831_i8,-4451203469832113430_i8, &
 6305975856950141752_i8, 1646166081499768350_i8,  572923998387970306_i8, 6804243196150028565_i8, &
  667065245492146543_i8,  544994055559663752_i8, -984826663649643948_i8,-7846031982474062388_i8, &
-8891426057034643907_i8, 5730724361448381390_i8, -447885708775187580_i8, 8773248901941860797_i8, &
-7170437794793168416_i8,-5398991814221986096_i8,-5366337817214164824_i8, 3526989999175582203_i8, &
-2604479866424677967_i8,-5952765826193359989_i8,-7097675576384595715_i8, 5905360391790753868_i8, &
-7252707270090012207_i8, 8439547541703114846_i8, -216020028091014691_i8,-8164641071954684944_i8, &
-1563616323283969374_i8,-8060369629099600700_i8, 2068658560870983886_i8, 2788238388030627072_i8, &
-8777449485991976369_i8,-4011216747555825340_i8, 8889663533175001894_i8,  735875252765143814_i8, &
-3159265721447535561_i8,-7357115328633340312_i8, 5725199588627970794_i8, 8414521079199955343_i8, &
 8768824135507373953_i8,-4524528821763445428_i8, 7581942940273646743_i8,-5118330390812221323_i8, &
-4488202363656325066_i8,  851410776825198771_i8,-1666853098161960511_i8, 3250658053512818284_i8, &
-4026600212547166972_i8,  128875888817146291_i8, 2788489803726088516_i8,-4622372802983833810_i8, &
 3616564210397987918_i8,-7820520222243752636_i8,-5635332484526049871_i8, 5447597949065243570_i8, &
 6168044909901060966_i8, 9052418063327834648_i8, 5142344975766880860_i8,-5411369245878172204_i8, &
-7379360784037338877_i8,-1195932203148768615_i8,  695531503582276069_i8,-3583457296864683048_i8, &
 3801718604005495273_i8, 4320165994194333632_i8,-1434118519472177719_i8,-3540850644557409322_i8, &
 4770735167731977227_i8,   35994434284898182_i8, -457244861120606792_i8,-9147758772590363291_i8, &
-8212461546684293568_i8, 1606726488497154766_i8, 1299698384585653329_i8,-6382665001263099869_i8, &
-7651817015561850791_i8,-3003872935205202296_i8, 5236492587935195461_i8, 1390616319464127710_i8, &
 8721746875076087988_i8,-1998970377505486207_i8, 1244250833332222488_i8, 7667372107410955828_i8, &
 5361142966006255735_i8, 8656271664247204431_i8,-1700439526713877978_i8, 1403535379469775414_i8, &
 4809098206772771406_i8,-1374131986529546747_i8,-2280641748630342267_i8,  769933896464430815_i8, &
-8050612897388895414_i8,-6343319878452183644_i8,-8642630888819226569_i8, 5583442762778128649_i8, &
 -959867218485420282_i8,-6650712954622673941_i8, -988246581351054466_i8,-6485432967294937956_i8/
data (mpegammacon(i), i =   400,   599) / &
 3283551738547613652_i8,-8953812689099810705_i8, 6868488079118869595_i8,-6194112097952345926_i8, &
 3543878939976298022_i8,-4580649827616233091_i8, 3805135673304866725_i8, -511838171886972821_i8, &
-8306490267897303706_i8,-2011480788351647811_i8,-2696021756982700706_i8, 6711318072551096097_i8, &
-1341247484571331318_i8, 5736941658322278213_i8,-5166416171891211437_i8,-8028122998929169779_i8, &
-7280790334783894306_i8, 3482945894059694157_i8, 8292639992339890954_i8,-3497242200571030422_i8, &
 -171402236010717212_i8, 4113994870366021929_i8,-8813758330978607592_i8, 4398858919594833079_i8, &
-5042133894241433832_i8,-7443926926937675154_i8, 8267849957250697086_i8,-7456235577935866311_i8, &
-2411876286249273169_i8,-7699515985697800484_i8, 8069237874598735341_i8,-8692667239037631484_i8, &
 9064795129393934616_i8, 3669784292830495039_i8, 1969516240965149490_i8, 2824897083830721198_i8, &
 3906707430483342813_i8,-3795995994694317345_i8,-3783732028413306766_i8, 8477193872926832627_i8, &
 5833881701999883573_i8, 2592083930610974941_i8,-5798337836882763207_i8,-2951968008262821447_i8, &
  897486815225765080_i8,-7237997863515902893_i8, 5111074176659168264_i8,-2532631712601843285_i8, &
 1460210460172658774_i8, 2491945682906712383_i8, 7807600055741485405_i8, 4915989056553452168_i8, &
-4252451506055154305_i8,-6446063849002148428_i8,-6470486470446996238_i8, -865371042202660095_i8, &
 3437244528915463188_i8, 6917599461821772065_i8,-6056106689570610741_i8, 6915162412800655869_i8, &
 3264806532914548490_i8, 9176381906160097492_i8,-5965277520698845021_i8, 8865236541274562355_i8, &
 3460439369365216130_i8,  890156613557719042_i8, -385447534429052611_i8,-4056928822250428152_i8, &
 5879494060578787928_i8,-2485322714980252744_i8,-7954009916556211878_i8, -307877306748981998_i8, &
 5490488366604041180_i8,-2141052105472891815_i8,-8669697748957807642_i8,-6159532769448544013_i8, &
-2474966656930231886_i8, -857355794331012430_i8, 8180631509577783143_i8,-3873196138781370694_i8, &
 4138644325879358168_i8, 1926615100677823782_i8, 7731933451587744705_i8, 3607492660238756890_i8, &
-1870395967351503662_i8, 3949396262619783309_i8,-2955299632214821181_i8, 6447084745752371800_i8, &
-3082772135873212076_i8, 7550301046099000219_i8,-6083891512407957047_i8, 6870569636013562481_i8, &
-2226161171324394972_i8,-2876613217657678825_i8,-3588425955917577461_i8,-3496939956581743476_i8, &
-3890638324664055600_i8,-4978694067539374120_i8, 2197267750109225006_i8, 5399800822479237053_i8, &
-2907108942239436522_i8,-6364721770869682151_i8, -368930960036745196_i8,-5628565071087135828_i8, &
 3714952314082344519_i8, -132423375068319095_i8,-5128966852684397973_i8, 3424872068634048913_i8, &
 6799699059877282916_i8, 9039974720951580717_i8,-9146075474922976850_i8,-2838637509981546076_i8, &
 -801373905966498967_i8, 6697786213634233298_i8, 6803062719996246705_i8, 2032376409028495115_i8, &
-4054630382620139141_i8, 6084429207756381469_i8,-7479090774607832216_i8,-7676438029240337177_i8, &
 8990324524409457767_i8, 7135499624454688421_i8,-8911247236629444429_i8,-7573896995982790235_i8, &
 3333079652968468651_i8,-4783673933392325250_i8, 6266957022380515887_i8,-3209965486278029115_i8, &
-3730289796777999340_i8,  -72858829893159427_i8, 3388833521348189025_i8, 8282636257854065999_i8, &
-8875040102818175875_i8,-9200320915135883653_i8,-1761488019655160713_i8, 7118887537683526700_i8, &
 5099529883230491132_i8, -243363554746133304_i8, 3358368524144778894_i8, 1340893642008146868_i8, &
 7285543776009799696_i8, 8713355257151264687_i8, 5926218094444213917_i8, 7204623351039865828_i8, &
 4952989713375921982_i8, 5758269340080791194_i8,-1056516115218335273_i8, 8426278508015266854_i8, &
 3658168238303899620_i8, 5000540659083253587_i8, -945732351257373058_i8,-5309547276568388652_i8, &
-1817644087886698840_i8, 1018540754821318608_i8,-7424672880520303011_i8,-7476386346222058803_i8, &
 3154234255258880887_i8, 1337297998815284373_i8, 6850907649193264195_i8, 8725295218718604244_i8, &
-9112421549521408826_i8,-3741005266890164203_i8,-8706514974654303490_i8, 1632247131605712139_i8, &
 2973088404685527608_i8,-5913481196689343528_i8,-3534348349039548771_i8,-8517973941810041256_i8, &
-1863696625188216874_i8,-5827875826758058327_i8,-1823443913006818445_i8, 3820929728499560098_i8, &
-4953829047518990092_i8, 7399609013588662748_i8,  700717575759503595_i8,-1279990589979629485_i8, &
-2267846886018703276_i8,-2299383971508568780_i8,-4836284140246906077_i8, 6200920785254361589_i8, &
-5158679896777214103_i8,-7462156914880092317_i8,-6548476496730996182_i8,  199300834068989137_i8, &
 8787531755364369116_i8,-3365658809133188161_i8,-8319682135341440127_i8, 6393755720572512870_i8, &
 8882966694912771410_i8, -409934037486542013_i8, 5792959771715196719_i8,-1431976658132334642_i8, &
 1766790250239830625_i8, 2301563450546013089_i8,-9118186204979862254_i8, 6409200244622393394_i8, &
 1312950678542820607_i8, 8202209205179519622_i8,-4279832642539200655_i8, 1684699966812766052_i8/
data (mpegammacon(i), i =   600,   799) / &
 -433687024351714870_i8, 3593359335716116174_i8, 1806946022913027972_i8,-2583590944355368359_i8, &
-8117819530224879865_i8, -482201553975517455_i8,-1550277829313480705_i8,-5715046085015461386_i8, &
 1614839550654624191_i8,-4568139284559210125_i8, 7394653136473657055_i8, 7947709800245042439_i8, &
-4325809727188127169_i8,-7269406008521260397_i8,-6760836240834928734_i8,-3108581336566481892_i8, &
-7676728853404415857_i8, 7795695530999857977_i8,  381381504401758706_i8,-4219166934778365994_i8, &
-7856477021214833615_i8, 3654651467220614644_i8,-5287761017231010106_i8, 2957116522245750032_i8, &
 5367719029056407803_i8,-7539513980843468819_i8,-1477158096552624713_i8, -797654147663029821_i8, &
 1978490069871679753_i8, 4806088966962228018_i8, 7235434089709452043_i8,  464343400325474800_i8, &
 7253386416709444984_i8, -565219920619987303_i8, 8999184609292250464_i8,  149890064952507904_i8, &
-3562992652586352163_i8, 4057959489403363511_i8,-3365640410972760572_i8, 7072299235206706811_i8, &
-3574099007682342182_i8,-8158477905224366949_i8, 5354419755627510124_i8,-7970916966255415241_i8, &
 8976657424142599591_i8,-4393954433857853369_i8, -336941372584650952_i8,-1878977990100788558_i8, &
 8921182424536412965_i8, 1401893454764929707_i8, 4072047110956367320_i8,-7307970425216675508_i8, &
 1853272442200216562_i8,-6292068231145856916_i8, -701132390224204874_i8,-4132664777866597175_i8, &
-4382017207298509565_i8, -294424032748944070_i8, 5638945109754780667_i8,-8622704664241019994_i8, &
 3997954076563431950_i8, 5630870546820330394_i8,-7732219022697534820_i8,-4988175302110175798_i8, &
-7719286670141420699_i8,  188653526281601423_i8,-5419140808942262438_i8, 6704881003997664470_i8, &
-5561857023526964926_i8,-3818724588538562713_i8,-5015906356027024742_i8, 7630981949034191703_i8, &
 1688972262841795309_i8, 5239430054142952227_i8,  270812167646473395_i8, 8474064978386863901_i8, &
 6502592291158813063_i8, 4357271499907123323_i8,-3762589065160088259_i8, 2598001892272785750_i8, &
 5242881866857901855_i8, 3425493536371874654_i8, 7840437988997159382_i8,-2091153024932299849_i8, &
 2935607263759599716_i8, -549657070848462263_i8, 1586344358297385959_i8,-5441728841620624149_i8, &
 5011016054542649372_i8,-4142027773335682193_i8, 1706310107242968514_i8, 5495899881533247119_i8, &
-7451938049949395628_i8,-3481696572028443690_i8,-1472034890735751418_i8,-7844779244933606922_i8, &
 5249170832705879302_i8, 3660735913618390008_i8, 3311620562394910999_i8,-5273209053931137378_i8, &
 1136836095807016796_i8, -819521188990328255_i8, 6317141815422682058_i8, 1585507478342879484_i8, &
-3270270221551703859_i8, 4331245701332385116_i8, -796941315555521244_i8,  948600316920056961_i8, &
 1738172306591391770_i8, 4683898492930042922_i8,-8880122880388485563_i8,-8320542813704280692_i8, &
-2116634872674697950_i8, -637521765162067773_i8, -692047677692920542_i8,-1329288478718940629_i8, &
 -189800549003209392_i8, 6230283683792051851_i8, 4215465917127813567_i8, 1390351908807937494_i8, &
-2563858673480074549_i8,-3552345598592728189_i8, 9012661928089961996_i8,-1014955404875648906_i8, &
 8963844106411901862_i8, 8726940838750424166_i8,-4797044543900541442_i8, 3438801435362466428_i8, &
 5620360345158554575_i8,-6553033687990112909_i8, 9211090673428781983_i8, -683743715604117860_i8, &
 -355487940908609726_i8, 2951381715813687293_i8,-3984524331251707948_i8,-2585979028776098302_i8, &
-1827275173049472377_i8, -974878487083500221_i8, 3693406205897138975_i8,-2165511864566037392_i8, &
 3311122038776602833_i8, 4083557420302399428_i8,  374958962523039166_i8,-3938024896142130589_i8, &
-4999358933494893695_i8,-5674495696487461071_i8,-3350253885387920389_i8, 3356841173760149279_i8, &
 -561516818586616860_i8, 4588461415824286385_i8,-8661899351543125048_i8, 4295825990732810634_i8, &
 1214176925067901932_i8, 7357669114283183890_i8,   55604627105234963_i8,-1511975007717439107_i8, &
 6904562675548226791_i8,-5149860076008393561_i8, 8457186239699639284_i8, 1371022135550132452_i8, &
 7135423015383870875_i8, -203250889791790424_i8, 1757675113934386140_i8,-4884354964112215136_i8, &
-9014432496353911337_i8,-7922464216981820949_i8, 2835305912341709802_i8,-5653133012557847702_i8, &
-8646596389830897442_i8, 5332197807375377188_i8,-2664214637020735372_i8, -478352218985975926_i8, &
 4961378238094698256_i8, 2356942992359433421_i8, 4930048561896770901_i8, 8747652560692603519_i8, &
  496538013290776596_i8, 3326553043573890625_i8,   -6566191032826510_i8,-4194082628873848037_i8, &
-1446009285357077821_i8, 8708625878172635500_i8,-3891913248662627424_i8,-6700518340495426360_i8, &
 8748885983730974572_i8, 7095137392682433843_i8,-7819281117623243067_i8,  256380286488119672_i8, &
-4751701669037966455_i8,-2923814102027272014_i8, 6716715985941872515_i8, -509198794584419770_i8, &
 5739587816428644734_i8, 5186937171744427781_i8,-1398995914577287258_i8, 8486439940912209239_i8, &
 1232987878298900374_i8,  337439531106296815_i8, 3312805289468831739_i8, 7747274454570185783_i8/
data (mpegammacon(i), i =   800,   999) / &
 4885322216927101249_i8, 1365655136000606735_i8, 2335520260235504663_i8,-6002054324816851755_i8, &
 5248351591200058760_i8, 2562219690791040964_i8, 3755274893592273491_i8, 3047962181604683554_i8, &
 -343142132374520569_i8,-5995287436398847019_i8, 9221333626423136865_i8,-7654914226106010218_i8, &
-4642343154318938460_i8, 1090395595195941503_i8,-1921086413505781279_i8,-4742540121911376954_i8, &
-7130730662112238411_i8,-6516879756978397872_i8,-2460068989807431136_i8,-6307570994764554984_i8, &
-6217828269147934238_i8,  282339127424105056_i8, 3707501172957521588_i8, 8555227750664565100_i8, &
-8759366901424817929_i8,  893868986094519695_i8, -320197976797105499_i8,-8407999658189979551_i8, &
 5419370839017032144_i8, 7928629477897991090_i8, 8180154135448617488_i8,-4457128579878935886_i8, &
-1373789668255309223_i8, 6468470571129566113_i8, 6487557817594195585_i8,-6577620480649803799_i8, &
-2642705510514705813_i8,-1376824615741978066_i8,-5554860421443379882_i8,-6712853463925093992_i8, &
-4574356828142154008_i8,-3817200972874258827_i8, 2458525293981223842_i8,-1338959441990405338_i8, &
  529483554801511959_i8,-4719256299198657615_i8, 8033148818804459177_i8,-5670302842793206455_i8, &
-7565255619453597156_i8, -622469954671426071_i8, 1643264655990432459_i8, 7995431243432670495_i8, &
 9019904378009018985_i8,-4527363145853442710_i8, 6703117807217296947_i8,-1064405165948905677_i8, &
 1464943257747296486_i8, 2341773362472591644_i8,-5624471146552511014_i8,-1473241553930620982_i8, &
 6512865585769945421_i8, 7282003115753700386_i8, 1643931813558773977_i8,-2223464012719279638_i8, &
 1821365142094281093_i8, -277847630961529550_i8,  -37464142283806562_i8, 2729217665532350763_i8, &
 7003165658783744464_i8,  761956143904763358_i8, 4216173938680270911_i8,-6981975078259571091_i8, &
-3432308307882199586_i8, 4947294070942988699_i8,-6870247327516131104_i8, 6716941792430533162_i8, &
 1288688387022526197_i8, -670264989908588026_i8, 5374793403099399719_i8,  586679949273258412_i8, &
-6346072183235328322_i8, 7802578505304242912_i8,-4470302329819288937_i8,-8111103213052899995_i8, &
 8556627791144328980_i8, 1093958746371348098_i8,-3004964047688679176_i8,-3044500777594792660_i8, &
-3147831991528955757_i8,-3781192171490027515_i8, 1574170957793933955_i8, 3014112161331589857_i8, &
 1924302349353309848_i8,-6647337322634927519_i8,-3964100993603483228_i8,-2055975403680812907_i8, &
 1664492064410451791_i8,  880121710062385270_i8,-1592760360827190192_i8, 6230299465300549029_i8, &
 -406567018990975687_i8, 1539777702316513703_i8, 2986559641721717577_i8,-7411742578371099215_i8, &
 2731660303505975864_i8, 8512315976322533208_i8,-6318223336728610160_i8, 8399524810391978904_i8, &
 8506889220892927208_i8,-6329948465736679875_i8,-2995264307597048560_i8, 8916009558716834095_i8, &
-3350712543072278226_i8, 1758994014998986200_i8, 6556059180020450283_i8, 8167562328600600046_i8, &
 4193288561386646483_i8, 5916830404768924295_i8, 8601170735258382704_i8, 8180854768677251564_i8, &
 7032616151629782842_i8,-1963357413661221214_i8, 4580688662340130297_i8,  -85379965253319954_i8, &
-1791413059182375599_i8, 2438893315155939712_i8,-4359803526650985416_i8,-7775038673294954365_i8, &
  887295704253418668_i8, 8777132876171750185_i8, 7336252797658567036_i8,-7285831142392604913_i8, &
 1363520568310321602_i8, -351508401314132718_i8,-2568880098223973792_i8,-8386589445123124284_i8, &
-8643601854385304965_i8,-5391700563862865695_i8, 4010704142175954988_i8,-9052715907015127636_i8, &
 4769301852557304001_i8, 8379752547688825644_i8,-6731086300097783463_i8, 3794026056950011870_i8, &
 6302597406134166413_i8, 5625956677298659362_i8,-2492101758417703029_i8, 8375155270541315038_i8, &
 7256053837139186555_i8,-2564599128438131158_i8, 8051799488965226275_i8,-5450511211813622938_i8, &
 5442550872498116334_i8,-7516820577215395566_i8,-4743733253058396599_i8,-8025980140235345668_i8, &
 -807733733102115257_i8, 4864367618542069129_i8, 8010601372883590591_i8,-6938618668957833814_i8, &
 4887197642420823991_i8, 2141380016043324352_i8,-7878056878667942044_i8, 7628984521894222459_i8, &
 5020596061932927731_i8,-6444976584531749545_i8, 3072065235694451281_i8, 1558814790169472026_i8, &
 5830399423854255118_i8, 1427770738613163394_i8,-9165757315346079578_i8, 7748883084133122387_i8, &
-7493085625505915213_i8,-3401786506243239844_i8, 7512245294315834777_i8, 6547525115237778545_i8, &
-5931486451837979568_i8,  129576783763857870_i8,-1262291562965871849_i8,-2515140668428186199_i8, &
 7315044599626261443_i8,-3710141106797672826_i8, 7181305790239060563_i8, -330291354353026735_i8, &
 1960411336071058403_i8, 3765203941264663862_i8, 7688326336444541414_i8, 2993931597829888944_i8, &
-2117965979462943500_i8, 1613186950139690203_i8, 3478308986711914209_i8,-5267068656825274254_i8, &
  882525103245257015_i8, 3532839784177342520_i8,-1046801088089186201_i8,-7441315843633203504_i8, &
-7291274286883456425_i8, 1959881576078860820_i8,-9093701668542140335_i8,-9100238560060869069_i8/
data (mpegammacon(i), i =  1000,  1046) / &
 6065961060824651171_i8,-7872483316125189914_i8,-9096808841385029574_i8, 1994959239140944760_i8, &
-1599836597690619881_i8,-9111957392512125497_i8, 4641165896535190119_i8,-5213371879197354975_i8, &
 9158273522311139632_i8,-3398490102027206653_i8,-6945539307920821902_i8, 7071692586214617969_i8, &
-1934016825467708635_i8,-5863188930544183986_i8,-5825247477209368128_i8,-4192225835172907399_i8, &
-2225356274242197822_i8, 8959158305304055180_i8, 5498204991353910788_i8,-8182957525436416208_i8, &
 2828794071356540108_i8, 9057542911172993048_i8, 3673445014992529925_i8,-4574546530720130788_i8, &
 8055439779551189337_i8,  244699926518839689_i8, 6520038433821218850_i8, 9006607781494646232_i8, &
-8087754264396077148_i8,-5381828980692823905_i8,-7632120722202301859_i8, 6803464526321796934_i8, &
 4523798143493044002_i8,-3269074440357414812_i8,  867458361769572463_i8,-8460344680648168786_i8, &
-2600900012186847537_i8, 6403758549134399283_i8,-2000928146088808470_i8, 1177320291237583368_i8, &
-3430444618811942959_i8,-8193356166732320530_i8,  865780969705766845_i8,-6787263034787315687_i8, &
-3333156850902054058_i8,-7798994427934881884_i8,                   0_i8/

end module mpfuna


